@@ -1,12 +1,12 @@
 package Text::Table::Any;
 
-our $DATE = '2015-12-19'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $DATE = '2016-09-03'; # DATE
+our $VERSION = '0.02'; # VERSION
 
 #IFUNBUILT
-# use 5.010001;
-# use strict;
-# use warnings;
+# # use 5.010001;
+# # use strict;
+# # use warnings;
 #END IFUNBUILT
 
 sub _encode {
@@ -48,8 +48,13 @@ sub table {
     } elsif ($backend eq 'Text::ASCIITable') {
         require Text::ASCIITable;
         my $t = Text::ASCIITable->new();
-        $t->setCols(@{ $rows->[0] });
-        $t->addRow(@{ $rows->[$_] }) for 1..@$rows-1;
+        if ($params{header_row}) {
+            $t->setCols(@{ $rows->[0] });
+            $t->addRow(@{ $rows->[$_] }) for 1..@$rows-1;
+        } else {
+            $t->setCols(map { "col$_" } 0..$#{ $rows->[0] });
+            $t->addRow(@{ $rows->[$_] }) for 0..$#{$rows};
+        }
         return "$t";
     } elsif ($backend eq 'Text::FormatTable') {
         require Text::FormatTable;
@@ -100,7 +105,7 @@ Text::Table::Any - Generate text table using one of several backends
 
 =head1 VERSION
 
-This document describes version 0.01 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2015-12-19.
+This document describes version 0.02 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2016-09-03.
 
 =head1 SYNOPSIS
 
@@ -182,10 +187,6 @@ ruled line). But some backends won't display differently.
 
 =back
 
-=head1 SEE ALSO
-
-L<Bencher::Scenario::TextTableModules>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Text-Table-Any>.
@@ -202,13 +203,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Bencher::Scenario::TextTableModules>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
